info_sidra: List the parameters of a SIDRA table

View source: R/info_sidra.R

info_sidraR Documentation

List the parameters of a SIDRA table

Description

Uses the official JSON table descriptor to return variables, periods, classifications, categories, and geographic levels available in a table.

Usage

info_sidra(x, wb = FALSE)

Arguments

x

A numeric SIDRA table code.

wb

Logical. When TRUE, open the official HTML descriptor in the default browser. When FALSE, return structured metadata.

Value

When wb = FALSE, a list with components table, period, variable, classific_category, and geo. When wb = TRUE, the descriptor URL is returned invisibly after the browser is opened.

Author(s)

Renato Prado Siqueira rpradosiqueira@gmail.com

See Also

get_sidra()

Examples

## Not run: 
info_sidra(7060)
info_sidra(7060, wb = TRUE)

## End(Not run)

sidrar documentation built on July 24, 2026, 1:07 a.m.