| info_sidra | R Documentation |
Uses the official JSON table descriptor to return variables, periods, classifications, categories, and geographic levels available in a table.
info_sidra(x, wb = FALSE)
x |
A numeric SIDRA table code. |
wb |
Logical. When |
When wb = FALSE, a list with components table, period,
variable, classific_category, and geo. When wb = TRUE, the
descriptor URL is returned invisibly after the browser is opened.
Renato Prado Siqueira rpradosiqueira@gmail.com
get_sidra()
## Not run:
info_sidra(7060)
info_sidra(7060, wb = TRUE)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.