| sidra_locations | R Documentation |
List the locations available for a SIDRA table
sidra_locations(
table,
level,
refresh = FALSE,
cache = FALSE,
ttl = 1800,
cache_dir = NULL
)
table |
A single SIDRA table code. |
level |
A single geographic level, with or without the |
refresh |
A single logical value. When caching is enabled, bypass and replace an existing entry. |
cache |
A single logical value. Cache normalized catalog or metadata
responses on disk. The default is |
ttl |
A positive cache lifetime in seconds. The default is 30 minutes. |
cache_dir |
Optional cache directory. By default, the platform-specific
user cache directory for |
Locations come from the official table- and level-specific version 3 endpoint. Location identifiers are SIDRA territorial identifiers; they must not be coerced to numeric values or assumed to be census tract codes.
A base data.frame() with columns table_id, level_id,
level_name, location_id, and location_name. All identifiers are
character vectors.
Renato Prado Siqueira rpradosiqueira@gmail.com
sidra_metadata()
Other SIDRA discovery functions:
sidra_catalog(),
sidra_metadata(),
sidra_periods()
## Not run:
sidra_locations(7060, "N6")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.