| sidra_periods | R Documentation |
List the periods available for a SIDRA table
sidra_periods(
table,
refresh = FALSE,
cache = FALSE,
ttl = 1800,
cache_dir = NULL
)
table |
A single SIDRA table code. |
refresh |
A single logical value. When caching is enabled, bypass and replace an existing entry. |
cache |
A single logical value. Cache normalized catalog or metadata
responses on disk. The default is |
ttl |
A positive cache lifetime in seconds. The default is 30 minutes. |
cache_dir |
Optional cache directory. By default, the platform-specific
user cache directory for |
Data come from the official table-specific version 3 period endpoint. Period identifiers are kept as character strings so leading zeros and non-calendar codes cannot be lost.
A base data.frame() with columns table_id, period_id,
period_name, alternative_names, and modified. The
alternative_names column is a base list-column of character vectors.
Renato Prado Siqueira rpradosiqueira@gmail.com
sidra_metadata()
Other SIDRA discovery functions:
sidra_catalog(),
sidra_locations(),
sidra_metadata()
## Not run:
sidra_periods(7060)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.